Welcome to flask-matomo2
========================================

`flask-matomo2` is a library which lets you track the requests of your Flask website using Matomo (Piwik).

Table Of Contents
-----------------

.. toctree::
   :maxdepth: 2

   getting_started
   configuration
